package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````!14``#0````X@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````B&X`
M`(AN```%```````!``$```#`?0``P'T!`,!]`0!\`@``K!(```8```````$`
M`@```,A]``#(?0$`R'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3`?0``P'T!`,!]`0!``@``0`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$\````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3P```%````!4````
M60```%H```!A````8@```&,`````````90```&8`````````9P```&@```!K
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````8!`````````#``<```````"``0```````P`1``P`````
M`````````!(```#:`0`````````````2````%```````````````$0`````"
M`````````````!$```!\`0`````````````2````&P``````````````$@``
M`+D!`````````````!(````C```````````````2````*@``````````````
M$@````T"`````````````!(```#%`0`````````````2````,P``````````
M````(````$X#`````````````"$```!+```````````````2````40``````
M````````$@```%@``````````````!(````;`P`````````````2````#`,`
M````````````$@```)("`````````````!(```!?```````````````2````
M,P(`````````````$@```&8``````````````!(```#'`@`````````````2
M````;0``````````````$@```'4``````````````!(```"P`@``````````
M```2````?0``````````````$@```(,``````````````!(```",````````
M```````@````!0,`````````````$@```*@``````````````!(```"M````
M```````````2````'@(`````````````$0```,X"`````````````!(```!@
M`@`````````````2````M```````````````$@```%("`````````````!(`
M``!R`P`````````````2````V0(`````````````$0```$T#````````````
M`!$```"$`@`````````````2````.@,`````````````$@```$\#````````
M`````!$```"[```````````````2````,@,`````````````$@```,0`````
M`````````!$```"*`0`````````````2````U@``````````````(@```.4`
M`````````````"````#[```````````````2````_0(`````````````$@``
M`'`"`````````````!(``````0`````````````2````!@$`````````````
M(````+L"`````````````!(````@`0`````````````2````J@$`````````
M````$@```"4!`````````````!(```"@`@`````````````2````F0$`````
M````````$@```"L!`````````````!(````\`0`````````````2````+@(`
M````````````$@```'X``````````````!(````_`@`````````````2````
M>0(`````````````$@```"L#`````````````!(```!"`0`````````````2
M````(P,`````````````$@```%8!`````````````!(````I`@``````````
M```2````Z`$`````````````$@```%T!`````````````!(```!D`0``````
M```````2````3`,`````````````(0```'4!`````````````!(```!R!```
M;)`!```````0`!(`1P,``'$3``"4`0``$@`)`/H!```Q,0```@```!(`"@"T
M`P``K1\``*@$```2``D`@@0``*DF```X````$@`)`)$#``!9&P``!````!(`
M"0`F!```81````(````2``<`UP,``%4D``!4`@``$@`)`"P$```\@`$`````
M`!``$@!:!```71L``&0!```2``D`#P0``#R``0``````$``2`*(#``!!'P``
M;````!(`"0#!`P```1H``$`````2``D`R0,``/$>``!`````$@`)`.T#``"U
M+P``P@```!(`"0`"!```P1P``!(````2``D`&P0``&R0`0``````$``2`'T$
M``!LD`$``````!``$@!7`P``(14``$`````2``D`.@0``-,<``":````$@`)
M`/@#```X@`$`!````!$`$0!3!```/(`!```````0`!$`%`0```45````````
M$@`)`",$``!Y+P``/````!(`"0!@`P``,1\``!`````2``D`>P,``(D:``#0
M````$@`)`&<$``!W,```N````!(`"0!Q!```;)`!```````0`!(`1@0``&T=
M``"$`0``$@`)``!L:6)P97)L+G-O`&]P96YD:7(`<W1D97)R`')E86QL;V,`
M86-C97-S`'-N<')I;G1F`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K
M`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``
M;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P
M96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7W-T86-K7V-H:U]G=6%R9`!?
M7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S
M90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N
M;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!S
M=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"UA
M<FUV-RYS;RXQ`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D
M:7(`<W!R:6YT9@!S=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?
M7U]E;G9I<F]N`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S
M971U<%]L:6)P871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE
M86X`6%-?26YT97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L
M`'!A<E]B87-E;F%M90!?7V)S<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?
M8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P
M87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L
M96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`P'T!`!<```#$
M?0$`%P```+Q_`0`7````R'\!`!<```#4?P$`%P````"``0`7````"(`!`!<`
M```,@`$`%P```!2``0`7````&(`!`!<````<@`$`%P```""``0`7````)(`!
M`!<````L@`$`%P```#"``0`7````.(`!`!<```#`?P$`%04``,1_`0`5!@``
MS'\!`!4.``#0?P$`%1\``-A_`0`5(P``W'\!`!4I``#@?P$`%2T``.1_`0`5
M,```Z'\!`!4R``#L?P$`%3,``/!_`0`5.```]'\!`!4]``#X?P$`%3X``/Q_
M`0`50P``Q'X!`!8#``#(?@$`%@0``,Q^`0`6!P``T'X!`!8(``#4?@$`%@D`
M`-A^`0`6"@``W'X!`!8+``#@?@$`%@P``.1^`0`6#0``Z'X!`!8.``#L?@$`
M%A```/!^`0`6$0``]'X!`!82``#X?@$`%A,``/Q^`0`6%````'\!`!85```$
M?P$`%A8```A_`0`6%P``#'\!`!88```0?P$`%AD``!1_`0`6&@``&'\!`!8;
M```<?P$`%AP``"!_`0`6'0``)'\!`!8>```H?P$`%B```"Q_`0`6(0``,'\!
M`!8B```T?P$`%B0``#A_`0`6)0``/'\!`!8F``!`?P$`%B<``$1_`0`6*```
M2'\!`!8K``!,?P$`%BP``%!_`0`6+@``5'\!`!8O``!8?P$`%C$``%Q_`0`6
M,@``8'\!`!8S``!D?P$`%C0``&A_`0`6-0``;'\!`!8V``!P?P$`%C<``'1_
M`0`6.0``>'\!`!8Z``!\?P$`%CL``(!_`0`6/```A'\!`!8_``"(?P$`%D``
M`(Q_`0`600``D'\!`!9"``"4?P$`%D0``)A_`0`610``G'\!`!9&``"@?P$`
M%D<``*1_`0`62```J'\!`!9)``"L?P$`%DH``+!_`0`62P``M'\!`!9,``"X
M?P$`%DX```&UO>@!0'!'!.`MY03@G^4.X(_@"/"^Y4!N`0``QH_B%LJ,XD#^
MO.4`QH_B%LJ,XCC^O.4`QH_B%LJ,XC#^O.4`QH_B%LJ,XBC^O.4`QH_B%LJ,
MXB#^O.4`QH_B%LJ,XAC^O.4`QH_B%LJ,XA#^O.4`QH_B%LJ,X@C^O.4`QH_B
M%LJ,X@#^O.4`QH_B%LJ,XOC]O.4`QH_B%LJ,XO#]O.4`QH_B%LJ,XNC]O.4`
MQH_B%LJ,XN#]O.4`QH_B%LJ,XMC]O.4`QH_B%LJ,XM#]O.4`QH_B%LJ,XLC]
MO.4`QH_B%LJ,XL#]O.4`QH_B%LJ,XKC]O.4`QH_B%LJ,XK#]O.4`QH_B%LJ,
MXJC]O.4`QH_B%LJ,XJ#]O.4`QH_B%LJ,XIC]O.4`QH_B%LJ,XI#]O.4`QH_B
M%LJ,XHC]O.4`QH_B%LJ,XH#]O.5X1_WG`,:/XA;*C.)T_;SE`,:/XA;*C.)L
M_;SE`,:/XA;*C.)D_;SE`,:/XA;*C.)<_;SE`,:/XA;*C.)4_;SE`,:/XA;*
MC.),_;SE`,:/XA;*C.)$_;SE`,:/XA;*C.(\_;SE`,:/XA;*C.(T_;SE`,:/
MXA;*C.(L_;SE`,:/XA;*C.(D_;SE`,:/XA;*C.(<_;SE`,:/XA;*C.(4_;SE
M`,:/XA;*C.(,_;SE`,:/XA;*C.($_;SE`,:/XA;*C.+\_+SE`,:/XA;*C.+T
M_+SE`,:/XA;*C.+L_+SE`,:/XA;*C.+D_+SE`,:/XA;*C.+<_+SE`,:/XA;*
MC.+4_+SE`,:/XA;*C.+,_+SE`,:/XA;*C.+$_+SE`,:/XA;*C.*\_+SE`,:/
MXA;*C.*T_+SE>$?]YP#&C^(6RHSBJ/R\Y0#&C^(6RHSBH/R\Y7A'_><`QH_B
M%LJ,XI3\O.4`QH_B%LJ,XHS\O.4`QH_B%LJ,XH3\O.4`QH_B%LJ,XGS\O.4`
MQH_B%LJ,XG3\O.4`QH_B%LJ,XFS\O.4`QH_B%LJ,XF3\O.4`QH_B%LJ,XES\
MO.4`QH_B%LJ,XE3\O.4`QH_B%LJ,XDS\O.5PM8BPS>D&$`62!JD%J@>H34S_
M]USO34M\1.-8`Y-,2P.:XU@11AA&!)/_]\3N24OC6!YX2$OE6'ZY__<2[T=*
M>D0081"Y`2#_]U+O__=T[RAH__>F[X#X/6<H:/_WH.^0^)XS0_`"`X#XGC,H
M:/_WF.^0^)XS0_`!`X#XGC,'F`4PL/&`3P?3-4LV2.-8>$091@.3__=J[H``
M__="[P%&!IPQ2R)H>T0"8#!*F&!Z1$)@+TIZ1!)H@F`N2GI$0?@,+P0B6F`!
M(P>:FD(VW``A`O&`0P,S*$U`^",0`)$G27U$`T8#,BAI>43_]Y3N!$88N2AI
M__<([P1&(4U]1"AI__?,[A](>$0`\"3Y8+GK:".Y'4AX1`#P'?GH8!M+>T38
M:`BQ`?`(^1E+>T08:?_W2N__]_CM($8(L'"]5/@C4`$S0?@$7\#G+&L!`$0!
M``!``0``#`$``"`!``"D;`$`)`$``*,=```^;`$`R1\``!!L`0"^'P``!&P!
M`.4%``#H:P$`?1T``"0=``#&:P$`NFL!`$_P``M/\``.`TEY1&A&(/`/#.5&
M`/`"^+9H`0`?M0M+"TI[1)I8`I(*2II8`Y(`(@&2"4J;6`(=`),!:`*;`YC_
M]VCN!;!=^`3[`+^.:0$`'`$```0!```0`0``"$@)2PE*>$1[1(-">D2"L`70
M!TO36`&3"[$"L!A'`K!P1P"_TFH!`-!J`0!(:0$`&`$```I("TEX1'E$"QK9
M#PE*`>NC`4D0>D2"L`70!TO36`&3"[$"L!A'`K!P1P"_H&H!`)YJ`0`,:0$`
M.`$```Y+$+5[1`Y,&WA\1*.Y#4OC6".Q#$M[1!AH__<N[O_WM_\*2^-8&[$)
M2'A$__=T[0$B"$M[1!IP$+T`OV1J`0#::`$`,`$``!9J`0`4`0``AE@``#1J
M`0`(M0=+!TI[1)M8*[$&20=(>41X1/_W"NZ]Z`A`IN<`OX9H`0`T`0``!&H!
M`$98```82RWI\$=[1(I&!48XLQ9*FU@<:`2S`T8>1A/X`1LYN:%&=AO(1EGX
M!'LGN3Q&$^`]*?70\.<R1BE&.$;_]W#M`"COT;M=/2OLT:CK!`2D$,KX`$!T
M'#Q$($:]Z/"'!$;ZYP"_5F@!`"@!```'M0Q*#$MZ1--8:48;:`&33_```__W
MOO\(2@=+>D336!IH`9M:0`'0__<T[@.P7?@$^P"_ZF<!`"P!``#49P$`<[44
M2A1+>D336`1&&V@!DT_P``-N1A%-?40Q1B!&__>9_TBY#DH,2WI$TU@::`&;
M6D`-T/_W#NX*2P":ZU@;:`/K@@-::$/X!"L`*OK1Y.<"L'"]JF<!`"P!``"8
M9P$`B&<!`"@!```MZ?!/#49)2DE+>D336(6P&V@#DT_P``,+>`9&/2L(OP$U
M*$;_]]SM`JD'1C!&__==_]_X`)$$1OE$J+'_]]#MN$)$TP$\%?@!.P3X`3\`
M*_G1`"`X2C9+>D336!IH`YM:0&#0__?"[31+6?@#H-KX`+!;^"0PB[DQ2P3Q
M`@A[1!IH3^J("%JQ04981O_W4NS*^```H+E/\/\PV^<!-.CG`2)`1AI@__>F
M[`&0`"CRT%E&J/$(`O_WI.P!F\KX`##:^``PF$0`(TCX!#P"E#-&&$83^`$K
M"K$]*OG1%TL"-UGX`T"`&SA$W?@(D-3X`(#_]X#L2/@I```HS-`C:`*:4_@B
M(!;X`1L31A%P`3()L3TI]]$](AIP%?@!*P/X`2\`*OG1E><%L+WH\(\^9P$`
M+`$``!!G`0#P9@$`*`$``&IH`0`MZ?!',DHS2WI$TUB<L!MH&Y-/\``#!4;`
ML0-XL['_]];K!D:0L2Q/W_BP@-_XL)!_1/A$^40P1O_W%NP$1GBY,$;_]U3L
M*$;_]]SL)4HA2WI$TU@::!N;6D`UT/_W).T3-#E&($;_]_KK`"CCT$%&($;_
M]_3K`"C=T"A&__<.[8)&($;_]PKM4$0",/_W$.R"1B-&*D9)1O_WZ.QI1E!&
M__?*[`$P4$8+T`2;`_1P0[/U@$\%T?_WH_]01O_WMNRYY__W\.OXYQRPO>CP
MAP"__&4!`"P!``!_&```?!@``'T8``"T90$`$+462A9+>D2<L--8:48$1AMH
M&Y-/\``#__?NZ\BY!)L#]'!#L_6`3P+0L_4@3P;1`B$@1O_W=.NP^H#P0`D)
M2@=+>D336!IH&YM:0`/0__>X[``@\^<<L!"]`+\690$`+`$``-ID`0`3M0I,
M"DM\1.-8&&C_]X#L"$L)2>-8>40!DPA+`9I[1`*PO>@00/_W9;P`OZYD`0`@
M`0``/`$``%$7```T5```$[4,2PQ*>T2<6"!H__=@[/_WUO\@:/_W7.P`(@=+
M"$E[1,WI`#('2GE$>D3_]S#K`K`0O6YD`0`@`0``AAD``!L7``#G"0``,+4N
M22Y*K?4`78>P>42*6`WU`%,4,Q)H&F!/\``"__<LZRA*`ZQZ1`"2)TH#1D'R
M`0$@1GI$__<"ZT,<#=$`(R)('TEX1`WU`%)!6!0R"&@1:$A`+=#_]SSLL/6`
M7P#9_]X-]8!5$#4@1D_T@%(I1O_WE.L$'N+;8!S_]R[K`T8`*-S0J$("T@(9
ME4+HTZM"`MDJ&9-"X]-!\@$"E$+?W")&&$8I1O_W_.L`(@-&`E7&YQA&#?4`
M70>P,+T@9`$`+`$``/86``#<%@``Z&,!`/_WEK\MZ?!/#$9+2:WU@UU*2GE$
MA[`%1DE(BE@-]8-3>$04,Q)H&F!/\``"__>>_2\A!D8H1O_W+.N(L4%(*49X
M1/_WY_U`23Q*>40-]8-3BE@4,Q%H&FA10&;0__?0ZRA&__?(ZSE)!T9Y1"!&
M__>>ZP1&W_C8@-_XV)#?^-B@^$3Y1/I$`"S8T"-X`"L(OT1&5K$A1C!&__>,
MZBBY+TEY1/_WA.L$1NWG($;_]Z+K(Q@`(!H;$_@!'2\I%-!['!-$L_6`7[G:
M#?%T"R-&2D9/](!16$;-Z0"E__=(Z@$PL/6`7P+9_]X8<./G`JPA1EA&__=.
MZZ"Y(VD#]'!#L_4`3P[1`2%81O_W*NI(N11(649X1/_W?OU81O_WG.H%1I'G
M$$D`('E$N^<H1@WU@UT'L+WH\(\`OTIC`0`L`0``,!8``!D6```28P$`_!4`
M`(<5``"R%@``Y!4``,85``!'%0``0!4```-&$_@!*P*Y<$<O*@B_&$;WYQ"U
M!$8(L0-X*[D?2'A$O>@00/_W8+K_]S#K`3@@1(1"`T8>TAIX`3@O*OC0&7@:
M1B\I`_'_,Q+1$T8!.YQ"&D8#TA%X`3LO*?C0$AN3'+/U@%\8V`$RLO6`7PW9
M_]Z<0N33G$+IT2-X+RL"T0A(>$3-YP=(>$3*YP=+(49[1!A&__=NZA"]`"#\
MYX$4```?%```>A0``!IC`0`PM49*1DMZ1(NPTUAJ1D5)&V@)DT_P``-Y1`'Q
M"@,!\2H$%488:%EH"#,#Q:-"*D;WT1N(/$@K@'A$__>M_#M(.TQX1/_WJ/PZ
M2'Q$>$3_]Z/\.4AX1/_WG_PX2'A$__>;_#=(>$3_]Y?\-DAX1/_WD_PU2'A$
M__>/_"!&__>,_#)(>$3_]XC\,4AX1/_WA/PP2'A$__=@_`%&$+$@1O_WK_PM
M2'A$__=7_`%&&+$K2'A$__>E_"I(>$3_]TW\`4:8L2A(>$3_]YO\)TDG2'E$
M>$3_]Y7\)DH12WI$TU@::`F;6D`8T/_W@NHB2'A$__<S_`%&$+$@2'A$Y.<?
M20HB>40-\1$`__>"Z0`HW=$<2`WQ&P%X1-;G"[`PO4)A`0`L`0``SE```!X4
M```=%```4Q0``!L4```<%```&Q0``",4``#0$P``'Q0``"44``"[$P``'Q0`
M`!X4```=$P``'!0``'@3```R%```IQ,``&Y@`0#X$P``FQ,``/43``!_$P``
M"+4+2WM$&V@!,PS1"4AX1/_WX/L@L0!X$+$P.!B_`2`%2WM$&&`%2WM$&&@(
MO0"_#&$!``$3``#N8`$`Z&`!``BU__<8ZO_W9.D`L0!H"+WWM19/!$9_1#A&
M__>[^R%&!48(L0-X*[D12'A$`["]Z/!``^3_]R[IL+D@1O_W[ND&1BA&__?J
MZ3!$`C#_]_#H!D8(2PA)(D9Y1`"5>T3_]\;I,48X1N'G`[#PO2@3```4$P``
M,A(```03```MZ?!/K?4`3;^P/JVE\5P*5$;?^!`4W_@0)'E$W_@,Y(I8#?4`
M0_Y$$FC#^/0@3_```O0S#O$0#`[Q!`.E\70&@$:3Z`<`AN@'`+SH#P`/Q)SH
M`P`.\2@.I?%H"83H`P">Z`<`B>@'`/%(\D]X1/_W4_M_1`1&J+$#>)NQ__>*
M_R!&__>^Z`1&ZTGG2GE$#?4`0XI8]#,1:!IH44``\+R!__>$Z?_W;O\$1BBY
M6?@$"P`H8='A3'Q$($;_]W+I0``!,/_W>.B!1H-&W4D!/'E$%/@!+P`J6=%:
M^`1+A+$@1O_W&OL$1@`H]M`#>``K\]#_]WS\`"COT"!&__>"Z`1&LD8TN5KX
M!&L`+E'0,W@`*T31($;_]T3I@T9(1O_W0.E81`#R!$M81O_W1.@&1L5+Q4E[
M1`"3Q4LB1GM$>43-^`20__<6Z4_TX'$P1O_WZ.@!,"_1__?>Z`-H$2LJT+Q*
MO$FX6`"3V/@`(#-&`&AY1/_WIN@`)(?G__?.^@`HE=`#>``KDM#_]SSHC>=8
M1@61"_$""__W[.@%F9GG,$;_]R7\`"BNT#!&__<JZ`1&J.<T1J[GI?'@!"%&
M,$;_]Q+H@D90L:)+I$GX6-CX`"`S1GE$`&C_]W3HS.<C:0/T<$.S]8!/[M'4
M^!B0__?FZ(%%Z-$C:</S"`.S]>!_XM%81O[WV.\$1I5(>$3_]X7Z`"A`\(&`
MV/@`<#A&__?"Z`,H@48AV8Y)!#AY1#A$_O>8[]"YN?$$#P30N409^`4\+RL2
MT=CX!("X\0`/#=!`1O_WJ.@#*`C9@TD$.'E$0$3^]X#O`"@(OT=&__=L_H%&
M`"A`\)V``48X1O[WR.^`1@`H`/"5@$_P`@I/\/\S;_`1`LWX`*`O'_[W6.\&
M(CE&0$;_]R;H%?@$/``K0=%[>$,K/M&[>$$K.]'[>$,K.-$[>4@K-=%[>44K
M,M%/\/\S;_`Y`D!&S?@`H/[W-N\I(CE&0$;_]P;H,D9?2V!)>T3-Z0!S7TMY
M1'M$($;_]SKH,$;_]Q;H6T@A1GA$__=9^B!&__=`_KCFV/@`</[W<N\!1CA&
M__=%_`=&`"A_]'6O<><`(P`B`)-`1@`C_O<&[P#P1?Z"1D_T`$(Y1D!&_O?0
M[P(>)]Q`1J7Q1`?^][[O,#U11CA&`/"Q_JA&W_@,H?I$*$911A?X`2L)\0$)
M_O?X[[GQ%`\%\0(%\M$`(XCX*#`Z2SM)>T3-Z0"#.DLR1GM$>42IYSE&4$8`
M\"[^RN<V239(>41X1/_W`_K^]\SN-$LT27M$S>D``S-+,D8@1GM$>43^]\[O
M,4TQ3]_XR(!]1']$^$1/].!Q($;^]YKO`3"%T?[WD.\#:!$K@-'^]ZKN"O$!
M"@"0*T8R1CE&($;-Z0&H_O>N[^7G($8-]0!-/["]Z/"/[EX!`"P!```N8`$`
MD!$``)9>`0!\7@$`'!(```L2``"U$0``HA$``-H0```(`0``?A$``%<1``#%
M$```4A$``"41``!.$0``D!```!X/``#T#@``:P\``*80``#D#P``=@X```X/
M``"?#@``>!```,,/``!&#@``-@X``,$/``!8$```+>GX3X!+@4I[1)Q8(&C^
M]U;O!48@:/[W4N^5^&0P@/AE,'M(>$3_]R/Y(+$#>#$K`=%#>`NQ__=O_"!H
M_O<^[W1)"R,!(GE$_O>>[CB[(&C^]S3O<$D#(P$B>43^]Y3N!48`*&31(&C^
M]RCO:TD#(P$B>43^]XCN!48`*'W0:$AX1/_W]?@&1@`H9]`@:/[W%N\R1NMH
M&6C^]X+N;>`!)<-HW_B`D9]IW_A\H?E$V?@$,"!HJT(%\?\X"-W^]_[N`"-"
M1CE&_O<*[@9&0+E72WM$6F@!.I!%N=$!)AU&(N#9^`@P`FA3^"6PDV@*Z@,#
ML_6`;P?1T6A81O[WWNT`*.71`373YR!H_O?8[C%H`B,`(O[W[.X!1N[G_O?0
M[CE&_O>([0$V:V@@:+-"]=R.YR!H_O?$[NMH/4H9:'I$_O<P[NMH&VB;:%L"
MC-4@:/[WMN[K:!EH_O?.[83G__=J^@9&(&B6L_[WJN[K:#)&&6C^]Q;N,$;^
M]XCN(&C^]Y[N!48@:/[WFNXJ20$B>43^]V3M*4H!1GI$*$;^]P+N(&C^]XSN
M`".`^&4P)$@D3'A$__=>^'Q$X&"`N:!H__?,_.!@6+D?2'A$_O=>[?[W=NX=
M2WM$FFCK:!)H7.<;3$_TX'%\1.!H_O=([A$H"M!#'`$K!]D#1J%H%4CB:`EH
M>$3^]T+MO>CXCUA:`0`@`0``:PT``,0.``"U#@``O0X``-T,``!46P$```0@
M`#!;`0#5#0``B@T``)4-``"F"P``3%H!`&L-```N6@$`'EH!`%0-```XM01&
M__<1^__W!OL%1O_W&_QPL6RQ(WA;L09)*$9Y1/[W?.V%0@31($:]Z#A`__?K
MN#B]S0L``"WI\$_\2OU+>D33L--8`:H41AMH49-/\``#`/%<!0#Q'`-3^`0;
M";J=0D3X!!OXT4`D$48-:DMK!#)K0(UH"6AK0$M`3^KS<P$\TV/QT>A*T.D`
MC`&9!&D11-#X".`A1,1HQ6B.Z@0*"NH,"HKJ!`H"G`'K^&$41%%$+$1/ZK@*
M`YV.ZKP+BNJ\!@OJ"`L.0!5$B^H."Z-$=40$G(;JO`8+Z_%K+D2*ZK$%!NO[
M9@6?!>H+!11$3^J["XOJL0F%Z@H%!.N\!"5$">H&"0:<%T0%Z_9E5T2)ZK$)
MB^JV"A1$N40*Z@4*">OU:03KL0%/ZK4%!YR*Z@L*BD2%ZK8!`>H)`11$7$0(
MGX'JM@$*Z_EJA>JY"R%$`>OZ80F<"^H*"Q=$3^JZ"@?KM@>*ZKD&%$0.0(OJ
M!0N&ZKD&)42[1"Y$"IT+Z_%KBNJQ!!5$!.H+!`;K^V8%Z[D)3^J["PN=A.H*
M!$Q$B^JQ"0GJ!@D51%5$B>JQ":E$#)T$Z_9DB^JV"A5$#9\*Z@0*">OT:07K
ML0%/ZK0$BNH+"@Z=BD071(3JM@$*Z_EJ7T0!Z@D!A.JY"X'JM@$+Z@H+%40%
MZ[8%.42+Z@0+`>OZ8:M$3^JZ"@^=BNJY!A5$#D`L1(;JN08F1!"<"^OQ:XKJ
ML0<41`?J"P<&Z_MF!.NY"4_JNPL1G(?J"@=/1(OJL0D)Z@8)%$141(GJL0FA
M1!*<!^OV9XOJM@H41!.="NH'"@3KL0&*Z@L*">OW:12<3^JW!XI$%40*Z_EJ
MA^JV`5U$A^JY"Q1$`>H)`0OJ"@N!ZK8!B^H'"P3KM@8I1+-$8TT5G@'K^F$N
M1$_JN@H6G#=$BNJY!DY`+$0+Z_%K%YHW1`3KN0D8GHKJL02$Z@L$!^O[9RI$
M3^J["Z%$+D0)Z_=IDD0&Z[$&B^JQ`HOJMP&!Z@D!>D`.1!F9DD0*Z_EJ*41/
MZKD)&IJ+1(GJMP$;G('J"@$J1`;K^F:+1`+KMP>)ZKH""^OV:W)`+$1/ZK8&
M')FA1(;JN@2$Z@L$%T0I1!V:!^O[9Z%$`>NZ`8;JNPH)Z_=IBNH'"BI$3^JW
M!QZ<%D2'ZKL"@NH)`BQ$44061!^:`>OY803KNPN'ZKD$!NOQ9DQ`*D1/ZK$!
MHT0Z1""<@>JY!W=`+$0Z1"&?"^OV:P3KN0F!ZK8$`NO[8H3J"P0'ZP4*3^J[
M"XI$B^JV`5%`BD0BF:%$*40)Z_)I(YPDGP'KM@:+ZK(!@>H)`0KK^6HL1$_J
MN0D.1"]$!NOZ9J-$!^NR!XGJL@2)ZKH"<D"$Z@H$%T0EFJ-$"^OV:RI$3^JV
M!B:<D42&ZKH"@NH+`B>9+$0'Z_MGD40'X)EY@EJAZ]ENS%<!`"P!```$Z[H$
MANJ["@GK]VF*Z@<**41/ZK<'*)H.1(?JNP&!Z@D!*D141`3K^60.1`+KNPN'
MZKD"!NOT9F)`3^JT!$3JN0H$ZKD%"NH&"NM)2NH%"BF=DT0-1`OK]FL]1$3J
MM@<$ZK8"!^H+!Q=#*IJJ1`KK^VH*1$_JNPL"Z[D"2^JV"1=$">H*"0OJM@))
MZ@()*YH'Z_IG"D1+ZKH%%$0]0`OJN@(50RR:H40*1`GK]VD"Z[8&3^JW!S5$
M1^JZ!@?JN@0&Z@D&)D,MG`7K^64,1%Q$1^JY"P?JN0(+Z@4+2^H""RZ:)D0*
M1`;K]68"Z[H*3^JU!=-$1>JY"@7JN0(*Z@8*2NH""B^:"^OV:PI$.D1%ZK8'
M!>JV!`?J"P<G0S"<DD0*Z_MJ#$1/ZKL+!.NY!$OJM@D+ZK8"">H*"4GJ`@DQ
MFB=$"D0'Z_IG%41+ZKH""^JZ!#I`(D,RG*E$#$0)Z_=I!.NV!D_JMP<R1$?J
MN@8'ZKH%!NH)!BY#,YT"Z_EB#41=1$?JN0L'ZKD$"^H""TOJ!`LTG"Y$#$0&
MZ_)F!.NZ"D_JL@+31$+JN0H"ZKD$"NH&"DKJ!`HUG`OK]FL,1#Q$0NJV!:)$
M!>H+!0+JM@0E0S:<"NO[:@Q$3^J["P3KN0E-1$OJM@D+ZK8'">H*"4GJ!PDW
MGP7K^F4/1$OJN@071"Q`"^JZ`A1#.)JY1`I$">OU:0+KM@9/ZK4%-$1%ZKH&
M!>JZ`@;J"0860SF:!.OY9`I$6D061$7JN0(%ZKD'(D`Z0SJ?!NOT9@]$3^JT
M!`?KN@=$ZKD*.D0*Z@8*!.JY!TKJ!PH[GP+K]F(/1#U$1.JV!U5$!^H""@3J
MM@=*Z@<*/)\%Z_)E.40!Z[D)T40]GT_JL@H^F5E*">OU:1=$$40\1(KJM@<!
MZ[8&BNJU`8'J"0%O0`Y$/YD\1`3K^6011$_JN0F*1(GJM0%A0(I$0)E!GQ%$
M!NOT9@'KM06)ZK0!"NOV:G%`%T1/ZK8&N42&ZK0'A^H*![E$0I\-1!=$0YD%
MZ_IE!^NT!(;JN@<)Z_5I;T`11$_JM04.1(7JN@&!Z@D!#D1$F3Q$$40$Z_ED
M`>NZ"H7JN0%A0(I$19D&Z_1F$41/ZK0$#41&GX3JN0%Q0!=$#41'F0KK]FH'
MZ[D)A.JV!P7K^F6'Z@H'$41/ZKH*#$2*ZK8!:4`,1$B9N4011`GK]6D!Z[8&
MBNJU`8'J"0$.1$F9!.OY9!%$3^JY"8I$2I^)ZK4!84`71(I$2YD&Z_1F!^NU
M!8GJM`<*Z_9J$41W0$_JM@:)1(;JM`&!Z@H!B41,F3U$$40%Z_IE`>NT!(;J
MN@%I0`Q$39D)Z_5I$41/ZK4%!.``O]R\&X_6P6+*#D2%ZKH!@>H)`0Y$3ID$
MZ_ED$40!Z[H*A>JY`0&K84"*1-/X.!'3^#PQ!NOT9A%$3^JT!!-$#41#1(3J
MN0$*Z_9J<4`#Z[D)A.JV`PU$@^H*`P7K^F5+1`/K]6,#8`[KN@.#8,-H"DH#
MZ[8&`VEE1!Q$"$MZ1$5@QF`$8=-8&FA1FUI``=#^]_CI4["]Z/"/8$\!`"P!
M```(M6`@_O?PZ`I*"TD"8`+QB#)"8`+Q*4*B]982HO:+8H)@HO&(,L)@`"+`
MZ002@F'"90B]`2-%9_#ATL,MZ?!!%D8%1D-IT@";&"B_@FE#822_`3*"88-I
M!?$<!P/K5G.#8<!M\+'`\4`$M$(X1*B_-$:(0@/2`QF90@#2_]Z(0@'K!`@!
MV4!%^-,B1O[WD.GK;2-$0"OK91?1*$;_]V3[048V&P7Q7`@_+A#<N4("V;L9
MF4+BT[E"`M*+&9]"W=,R1CA&_O=TZ>YEO>CP@;E"`=E!1=+3N4(!\4`#`=*?
M0LS3#$8Z1E3X!!N<0D+X!!OYT2A&__<X^T`^(4;4YRWI\$$!\1P'2VF.:0Q&
M@"&3^H/XP_/%`UH<."H%1C:Z^50'ZP(`0]T`(<+Q0`+^]TKH($;_]QG[."(`
M(3A&_O="Z"!&Q.D5:/_W#_OC>"!&*W!CB&MP(V@;"JMP(VCK<.-Y*W'CB&MQ
M8V@;"JMQ8VCK<>-Z*W)CB6MRHV@;"JMRHVCK<N-[*W/CB6MSXV@;"JMSXVCK
M<^-\*W1CBFMT(VD;"JMT(VGK=+WH\$'^]]FX`"'"\3@"PN<`OP&UO>@!0'!'
M+W1M<`!005)?5$U01$E2`%1%35!$25(`5$U0`%5315(`55-%4DY!344`+BX`
M)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ
M4$%2.CI"3T]4`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`!005)?4%)/1TY!
M344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!
M4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,
M1%],24)205)97U!!5$@`4UE35$5-`"4P,G@`)7,E<R5S)7,`<&%R+0`E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E
M<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;`!005(Z.E!A8VME<CHZ5D524TE/
M3@`Q+C`U,`!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*`"UE`"TM`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@
M6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@
M)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@
M)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N
M86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A
M<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD
M;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU
M;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L
M<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL
M92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P
M*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U
M9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5
M;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY
M("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D
M:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN
M<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA
M;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D
M92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L
M("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ
M3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO
M=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%
M(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O
M;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D
M>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`[
M"FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]
M"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI3
M2$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F
M:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M
M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E
M<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D
M9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N
M86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC
M;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P!?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````I%@``T14```$````!`````0```.@"```/````
MC@0```P```!A$```#0```#$Q```9````P'T!`!L````$````&@```,1]`0`<
M````!````/7^_V\L`0``!0```-0(```&````%`(```H```"L!```"P```!``
M```5``````````,```"X?@$``@```/`!```4````$0```!<```!P#@``$0``
M`(`-```2````\````!,````(````&`````````#[__]O`0``"/K__V\0````
M`````````````````````````````````````````````````````,A]`0``
M`````````&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0
M``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!``
M`&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```
M:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H
M$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0
M``!H$```:!```&@0``!H$```:!```&@0``!H$```<1,`````````````,3$`
M````````````81``````````````````````````````````````````````
M````````````@`$`_____S@Q``!C,0```````#TQ```],@``2#$``$\R``!0
M,0```````%0Q``!9,0```````/$S``!'0T,Z("A!;'!I;F4@.2XS+C`I(#DN
M,RXP`$$R````865A8FD``2@````%-RU!``8*!T$(`0D""@02!!,!%`$5`1<#
M&`$:`AP!'@0B`0`N<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD
M>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T
M97,`````````````````````````````````````````````````````````
M"P````$````"````%`$``!0!```8```````````````!`````````!,```#V
M__]O`@```"P!```L`0``Z`````,`````````!`````0````=````"P````(`
M```4`@``%`(``,`&```$`````P````0````0````)0````,````"````U`@`
M`-0(``"L!``````````````!`````````"T````)`````@```(`-``"`#0``
M\`````,`````````!`````@````V````"0```$(```!P#@``<`X``/`!```#
M````$`````0````(````/P````$````&````8!```&`0```(````````````
M```"`````````#H````!````!@```&@0``!H$```"`,`````````````!```
M``0```!%`````0````8```!P$P``<!,``,`=``````````````0`````````
M2P````$````&````,#$``#`Q```(```````````````"`````````%$````!
M`````@```#@Q```X,0``2CT``````````````0````````!9`````0````(`
M``"$;@``A&X```0```````````````0`````````8P````X````#````P'T!
M`,!]```$```````````````$````!````&\````/`````P```,1]`0#$?0``
M!```````````````!`````0```![````!@````,```#(?0$`R'T``/`````$
M``````````0````(````A`````$````#````N'X!`+A^``!(`0``````````
M```$````!````(D````!`````P````"``0``@```/```````````````!```
M``````"/````"`````,````\@`$`/(```#`0``````````````0`````````
ME`````$````P`````````#R````:```````````````!`````0```)T````#
M``!P``````````!6@```,P```````````````0`````````!`````P``````
>````````B8```*T```````````````$`````````
